==> haskell-cborg-json-0.2.2.0-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cborg-json
version:              0.2.2.0
visibility:           public
id:                   cborg-json-0.2.2.0-CrKI2p2tysK1gnMIvdR0TS
key:                  cborg-json-0.2.2.0-CrKI2p2tysK1gnMIvdR0TS
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  04d16edc576f0bfe34aec96d71e8e7f7
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cborg-json-0.2.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cborg-json-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/cborg-json-0.2.2.0
hs-libraries:         HScborg-json-0.2.2.0-CrKI2p2tysK1gnMIvdR0TS
depends:
    aeson-1.5.6.0-KLnW8ZNssug7g6SUFAYcU2
    aeson-pretty-0.8.8-4dcFgnpuJa6LwPAJRNk301 base-4.15.0.0
    cborg-0.2.5.0-JlL2iKxh0vc9IJW6Z4VJQD
    scientific-0.3.7.0-85gPhyHadbV4QYqa7IGCyM text-1.2.4.1
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cborg-json-0.2.2.0-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cborg-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cborg-json
version:              0.2.2.0
visibility:           public
id:                   cborg-json-0.2.2.0-IvyQx7gYIhG4uFG9i9nsoA
key:                  cborg-json-0.2.2.0-IvyQx7gYIhG4uFG9i9nsoA
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  61ca7ff1c576d97fe2e5dd9211f733cd
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.0.1/site-local/cborg-json-0.2.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cborg-json-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/cborg-json-0.2.2.0
hs-libraries:         HScborg-json-0.2.2.0-IvyQx7gYIhG4uFG9i9nsoA
depends:
    aeson-1.5.6.0-nrMp0b6teF7D3JqNhCf9o
    aeson-pretty-0.8.8-FK3M5jYjspp8sm7A4RICtL base-4.15.0.0
    cborg-0.2.5.0-Iy5isRl2VsyGO1XBhut6HL
    scientific-0.3.7.0-85gPhyHadbV4QYqa7IGCyM text-1.2.4.1
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
